@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2003 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2004 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -20,14 +20,16 @@
 
 #include <stdlib.h>
 
-#define DEFAULT_RANDCOUNT   50
+#define DEFAULT_RANDCOUNT   10
 #define DEFAULT_WORDLIMIT 1000
-#define RATE(X) ((double)(X)->correct / ((double)(X)->mistaken + 1.0))
+#define WORDLIST_VERSION     2
+#define HEADER            "# LaTrine wordlist file, version = %d.\n"
 
 struct word {
 	char     *lang[2];
-	unsigned correct;
-	unsigned mistaken;
+	unsigned long index;
+	time_t   timestamp;
+	double   rate;
 	size_t   pos;
 };
 
